/*
 * $Id$
 *
 * Definitions for mondoarchive
 */

/**
 * Compatibility #define to ease the transition to logfile-in-a-variable.
 */
char *MONDO_LOGFILENAME = "mondoarchive.log";
char *MONDO_LOGFILE = "/var/log/mondoarchive.log";
char *MONDO_OPTIONS = "0123456789A:B:C:DE:FGHI:J:K:LM:NOP:QRS:T:UVWYb:c:d:ef:gik:l:mn:op:rs:tuw:x:z";

/* No restriction on ps options */
char *ps_options = "auxww";
char *ps_proc_id = "$2";
